@@ -6,34 +6,24 @@ from poker_game_runner.utils import HandType, card_num_to_str, get_hand_type, ha
 class PlayerInfo: 
     """
         A class to represent the state of a player
-
-        Attributes
-        -----------
-        spent: int
-            the amount the player has spent in this game
-        stack: int
-            the amount the player has left
-        active: bool
-            true if the player has not folded in this game
     """
     spent: int
+    """the amount the player has spent in this game"""
     stack: int
+    """the amount the player has left"""
     active: bool
+    """true if the player has not folded in this game"""
 
 @dataclass(frozen=True)
 class ActionInfo: 
     """
         A class to represent the action of a player
-
-        Attributes
-        -----------
-        player: int
-            the index of the player taking this action
-        action: int
-            the action of the player
     """
     player: int
+    """the index of the player taking this action"""
     action: int
+    """the action of the player"""
+
     def __str__(self) -> str:
         player_str = "Player " + str(self.player) + ": "
         if self.action == 0:
@@ -46,110 +36,118 @@ class ActionInfo:
 class Observation: 
     """
     A class representing the state of the game
-
-    Attributes
-    ----------
-    my_hand: Tuple[str]
-        The cards in the current players hand
-    my_index: int
-        The index of the current player out of all players in the game
-    board_cards: Tuple[str]
-        The community cards on the board
-    player_infos: Tuple[PlayerInfo]
-        Current state of all players in the game
-    history: Tuple[Tuple[ActionInfo]]
-        The history of all actions taken so far grouped by game round
-    small_blind: int
-        The current small blind
-    big_blind: int
-        The current big blind
-    current_round: int
-        The current game round
-    legal_actions: Tuple[int]
-        all legal actions
+    
     """
-    my_hand: Tuple[str]
-    my_index: int
-    board_cards: Tuple[str]
-    player_infos: Tuple[PlayerInfo]
-    history: Tuple[Tuple[ActionInfo]]
     small_blind: int
+    """The current small blind"""
     big_blind: int
+    """The current big blind"""
+    my_hand: Tuple[str]
+    """The cards in the current players hand"""
+    my_index: int
+    """The index of the current player out of all players in the game"""
+    board_cards: Tuple[str]
+    """The community cards on the board"""
+    player_infos: Tuple[PlayerInfo]
+    """Current state of all players in the game"""
+    history: Tuple[Tuple[ActionInfo]]
+    """The history of all actions taken so far grouped by game round"""
     current_round: int
+    """The current game round"""
     legal_actions: Tuple[int]
+    """all legal actions"""
 
     def get_my_player_info(self):
-        """ return the PlayerInfo of the current player  """
+        """ :return: the PlayerInfo of the current player  
+            :rtype: PlayerInfo
+        """
         return self.player_infos[self.my_index]
 
     def get_my_hand_type(self):
-        """ return the hand type of the current player """
+        """ :return: the hand type of the current player
+            :rtype: HandType 
+        """
         cards = self.my_hand + self.board_cards
         return get_hand_type(cards)
     
     def get_board_hand_type(self):
-        """ return the hand type of the board cards """
+        """ :return: the hand type of the board cards 
+            :rtype: HandType
+        """
         if len(self.board_cards) == 0:
             return HandType.HIGHCARD
         return get_hand_type(self.board_cards)
 
     def get_player_count(self):
-        """ return the number of players in the tournament """
+        """ :return: the number of players in the tournament 
+            :rtype: int
+        """
         return len(self.player_infos)
 
     def get_active_players(self):
-        """ return the number of players that are active in the hand (have not folded) """
+        """ :return: the number of players that are active in the hand (have not folded) 
+            :rtype: Tuple[PlayerInfo]
+        """
         return tuple(p for p in self.player_infos if p.active)
     
     def get_actions_this_round(self):
-        """ return the ActionInfo's from the current round """
+        """ :return: the ActionInfo's from the current round 
+            :rtype: Tuple[ActionInfo]
+        """
         return self.get_actions_in_round(self.current_round)
 
     def get_actions_in_round(self, round_num: int):
-        """ return the ActionInfo's from the given round
-
-            Parameters
-            ---------
-            round_num: int
-                the round to fetch actions from
+        """ :return: the ActionInfo's from the given round
+            :rtype: Tuple[ActionInfo]
+            :type round_num: int
+            :param round_num: the round to fetch actions from (0,1,2 or 3)
         """
         if round_num > 3 or round_num < 0:
             return tuple()
         return self.history[round_num]
 
     def get_max_spent(self):
-        """ return the max spent from any player this game """
+        """ :return: the max spent from any player this game 
+            :rtype: int
+        """
         return max(map(lambda p: p.spent, self.player_infos))
 
     def get_call_size(self):
-        """ return the amount to call """
+        """ :return: the amount to call 
+            :rtype: int
+        """
         return self.get_max_spent() - self.player_infos[self.my_index].spent
 
     def get_pot_size(self):
-        """ return the amount in the pot """
+        """ :return: the amount in the pot
+            :rtype: int
+        """
         return sum(map(lambda p: p.spent, self.player_infos))
     
     def can_raise(self):
-        """ return true if the current player can raise """
+        """ :return: true if the current player can raise 
+            :rtype: bool
+        """
         return any(a for a in self.legal_actions if a > 1)
     
     def get_min_raise(self):
-        """ return the minimum possible raise.
-            will return 1 (call) if the current player cannot raise"""
+        """ :return: the minimum possible raise. Will return 1 (call) if the current player cannot raise
+            :rtype: int
+        """
         return min(a for a in self.legal_actions if a > 1) if self.can_raise() else 1
 
     def get_max_raise(self):
-        """ return the maximum possible raise (all in).
-            will return 1 (call) if the current player cannot raise"""
+        """ :return: the maximum possible raise (all in). Will return 1 (call) if the current player cannot raise
+            :rtype: int
+        """
         return max(a for a in self.legal_actions if a > 1) if self.can_raise() else 1
 
     def get_fraction_pot_raise(self, frac):
-        """ return the raise size in relation to the pot
+        """ :return: the raise size in relation to the pot
+            :rtype: int
 
-            Parameters
-            ----------
-            frac: float
-                The size of the pot to raise
+            :type frac: float
+            :param frac: The relative size of the pot to raise
 
         """
         if not self.can_raise():
